A simple example biallelic locus with made up allele frequencies. This is a list with two components, each of them vectors:

freqs

The frequencies of the different alleles. The names of the alleles are just "A" and "B".

geno_freqs

The expected frequencies of the possible genotypes given the allele freqs. The names are the names of the genotypes, which are the allele lengths separate by " / ".

data(example_L_biallelic)

Format

An object of class list of length 2.