install_mendel.RdThis checks the operating system and installs the correct version of mendel for you operating system (Mac, Linux, or Windows). To install the binary it downloads it from Eric's mbin repo on GitHub. It also installs in the same directory an intel libiomp DLL on Windows.
install_mendel(Dir = tempfile())No return value. Called for side effect of installing the 'mendel' binary.
if (FALSE) { # \dontrun{
install_mendel(Dir = system.file(package = "CKMRsim"))
} # }