return a list of values for a Mendel definitions file for gene dropping
mendel_control_list(ID, Reps, Seed)
Arguments
- ID
the name/prefix to be given to all the files involved in this run.
- Reps
the number of replicate simulations to perform
- Seed
an integer number to be used as the seed for the simulations.