merge_Qij.RdThis is a simple function that you will likely only ever need to use when you have split up the simulation burden to do many reps of the same scenarios, typically when you are parallelizing over different pairs of individuals with the same amount of missing data. It is up to the user to make sure that this is used intelligently. i.e., don't merge Qij objects that were simulated in different fashions (i.e. linked and unlinked).
merge_Qij(Qlist)A Qij object with component names identical to that of the first Qij object on the list, with values that are the concatenated versions of all of the Qij values in the list. The attributes of the return item are the same as the first Qij object on the list.