read_mendel_outped.RdNot sure exactly how I am going to do this, as we need to include genotyping error on there as well. Crap. But at least I have a start on how to parse this monstrous file. This assumes that the focal pair of individuals are labeled 1 and 2.
read_mendel_outped(Input, NumA, verbose)if (FALSE) { # \dontrun{
read_mendel_outped("/Users/eriq/Desktop/mendel-example-Ped.out")
} # }