example_L_biallelic.RdA simple example biallelic locus with made up allele frequencies. This is a list with two components, each of them vectors:
The frequencies of the different alleles. The names of the alleles are just "A" and "B".
The expected frequencies of the possible genotypes given the allele freqs. The names are the names of the genotypes, which are the allele lengths separate by " / ".
data(example_L_biallelic)An object of class list of length 2.