example_L_microhap.RdA simple example microhaplotype locus with three SNPs and six alleles. This was taken from a rockfish data that we had in the lab. This is a list with two components, each of them vectors:
The frequencies of the different alleles. The names give the sequence of SNP alleles at the microhaplotype.
The expected frequencies of the possible genotypes given the allele freqs. The names are the names of the genotypes, which are the allele names separated by " / ".
data(example_L_microhap)An object of class list of length 2.