example_L_microsat.RdThese data are from Locus SFOC113 from Ruzzante et al. It is included mostly to show how one might make a microsatellite genotyping error model. This is a list with two components, each of them vectors:
The frequencies of the different alleles. The names are the allele lengths.
The expected frequencies of the possible genotypes given the allele freqs. The names are the names of the genotypes, which are the allele lengths separate by " / ".
data(example_L_microsat)An object of class list of length 2.