Gene-drop true linked genotypes for the two focal individuals in a pedigree

linked_gene_drop_true_genotypes(
  kid,
  pa,
  ma,
  n_alleles,
  map_pos,
  chrom_id,
  chrom_start,
  chrom_end,
  freqs,
  reps,
  min_crossovers = 0L
)

Arguments

kid

integer vector of pedigree IDs.

pa

integer vector of paternal IDs, with 0 for founders.

ma

integer vector of maternal IDs, with 0 for founders.

n_alleles

integer vector with the number of alleles at each locus.

map_pos

numeric vector of map positions in centiMorgans.

chrom_id

integer chromosome ID per locus.

chrom_start

one-based start locus index for each chromosome.

chrom_end

one-based end locus index for each chromosome.

freqs

list of allele-frequency vectors, one per locus.

reps

number of replicate gene drops.

min_crossovers

minimum number of crossovers in the typed marker span of each chromosome for each meiosis.

Value

A list with integer matrices indiv1 and indiv2.