linked_gene_drop_true_genotypes.RdGene-drop true linked genotypes for the two focal individuals in a pedigree
linked_gene_drop_true_genotypes(
kid,
pa,
ma,
n_alleles,
map_pos,
chrom_id,
chrom_start,
chrom_end,
freqs,
reps,
min_crossovers = 0L
)integer vector of pedigree IDs.
integer vector of paternal IDs, with 0 for founders.
integer vector of maternal IDs, with 0 for founders.
integer vector with the number of alleles at each locus.
numeric vector of map positions in centiMorgans.
integer chromosome ID per locus.
one-based start locus index for each chromosome.
one-based end locus index for each chromosome.
list of allele-frequency vectors, one per locus.
number of replicate gene drops.
minimum number of crossovers in the typed marker span of each chromosome for each meiosis.
A list with integer matrices indiv1 and indiv2.